@@ -3,16 +3,20 @@ package YAML::PP::LibYAML;
 use strict;
 use warnings;
 
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use base qw/ YAML::PP Exporter /;
 our @EXPORT_OK = qw/ Load Dump LoadFile DumpFile /;
 
+use YAML::PP::LibYAML::Parser;
+use YAML::PP::LibYAML::Emitter;
+
 sub new {
     my ($class, %args) = @_;
 
     my $self = $class->SUPER::new(
         parser => YAML::PP::LibYAML::Parser->new,
+        emitter => YAML::PP::LibYAML::Emitter->new,
         %args,
     );
     return $self;
@@ -26,19 +30,16 @@ sub Load {
 
 sub LoadFile {
     my ($file) = @_;
-    die "Not implemented yet";
     YAML::PP::LibYAML->new->load_file($file);
 }
 
 sub Dump {
     my (@data) = @_;
-    die "Not implemented yet";
     YAML::PP::LibYAML->new->dump_string(@data);
 }
 
 sub DumpFile {
     my ($file, @data) = @_;
-    die "Not implemented yet";
     YAML::PP::LibYAML->new->dump_file($file, @data);
 }
 
@@ -61,6 +62,7 @@ YAML::PP::LibYAML - Faster parsing for YAML::PP
     my $yp = YAML::PP::LibYAML->new;
     my @docs = $yp->load_string($yaml);
 
+    # Legacy interface
     use YAML::PP::LibYAML qw/ Load /;
     my @docs = Load($yaml);
 
@@ -114,6 +116,10 @@ it's still much slower than L<YAML::XS>. Benchmarks will follow.
 Constructor, works like L<YAML::PP::new> but adds L<YAML::PP::LibYAML::Parser>
 by default.
 
+=item load_string, load_file, dump_string, dump_file
+
+Work like in L<YAML::PP>
+
 =back
 
 =head1 FUNCTIONS
