@@ -3,7 +3,7 @@ package YAML::PP::LibYAML::Emitter;
 use strict;
 use warnings;
 
-our $VERSION = '0.002_001'; # TRIAL VERSION
+our $VERSION = '0.002'; # VERSION
 
 use YAML::LibYAML::API::XS;
 use YAML::PP::Writer;
@@ -13,15 +13,13 @@ use base 'YAML::PP::Emitter';
 
 sub new {
     my ($class, %args) = @_;
-    my $indent = delete $args{indent} || 2;
     my $self = bless {
-        indent => $indent,
+        %args,
     }, $class;
     $self->{events} = [];
     return $self;
 }
 sub events { return $_[0]->{events} }
-sub indent { return $_[0]->{indent} }
 
 
 sub mapping_start_event {
@@ -85,24 +83,17 @@ sub stream_end_event {
     my $events = $self->events;
     my $writer = $self->writer;
     $writer->init();
-    my $options = {
-        indent => $self->indent,
-    };
 
     if ($writer->can('open_handle')) {
         if (openhandle($writer->output)) {
-            YAML::LibYAML::API::XS::emit_filehandle_events(
-                $writer->open_handle, $events, $options
-            );
+            YAML::LibYAML::API::XS::emit_filehandle_events($writer->open_handle, $events);
         }
         else {
-            YAML::LibYAML::API::XS::emit_file_events(
-                $writer->output, $events, $options
-            );
+            YAML::LibYAML::API::XS::emit_file_events($writer->output, $events);
         }
     }
     else {
-        my $out = YAML::LibYAML::API::XS::emit_string_events($events, $options);
+        my $out = YAML::LibYAML::API::XS::emit_string_events($events);
         $self->writer->write($out);
     }
 
